@@ -96,8 +96,22 @@ class UseCaseOutcome:
             }
         )
 
-
     @staticmethod
     def _normalise_keys(d: dict) -> dict:
         # returns the dict with _ replaced with spaces and each word capitalised.
         return {key.replace("_", " ").title(): value for key, value in d.items()}
+
+    @staticmethod
+    def _normalise_logs(logs: list) -> list:
+        # returns the list of logs that are passed in, with each dict containing the same keys. Required for UI widget
+        keys = set([
+            key for item in logs for key in item.keys()
+        ])
+
+        for log in logs:
+            for key in keys:
+                if key not in log:
+                    log[key] = ""
+
+        # logs is mutable
+        return logs
